$TITLE TWO SECTOR
$offsymlist offsymxref

SET   I / S1, S2/ ;
*----------------------- PARAMETER DEFINITION -------------------------
   PARAMETERS
   BETA(I)   BETA
   A(I)      SHIFT PARAMETER
   ALPHA     ALPHA
   ;
*----------------------- VARIABLE DEFINITION -----------------------------------
   POSITIVE VARIABLE
   X(I)      OUTPUT
   COST(I)   PRODUCITON COST
   L(I)      LABOR FACTOR INPUT
   K(I)      CAPITAL FACTOR INPUT
   LS        TOTAL SUPPLY OF LABOR
   KS        TOTAL SUPPLY OF CAPITAL
   W         LABOR FACTOR INPUT PRICE
   R         CAPITAL FACTOR INPUT PRICE
   P(I)      PRODUCT PRICE

   C(I)      CONSUMPTION
   Y         INCOME
   U         UTILITY
   ;
   FREE VARIABLE
   XOBJ      TOTAL OUTPUTS     ;
*----------------------- EQUATION DEFINITION -----------------------------------
   EQUATIONS
   XEQ(I)    OUTPUT FUNCTION
   COSTEQ(I) COST FUNCTION
   LDEMEQ(I) LABOR DEMAND
   KDEMEQ(I) CAPITAL DEMAND
   LSEQ      TOTAL SUPPLY OF LABOR
   KSEQ      TOTAL SUPPLY OF CAPITAL
   XOBJEQ    OBJECTIVE FUNCTION

   CEQ1      CONSUMPTION DENMAND FOR 1
   CEQ2      CONSUMPTION DENMAND FOR 2
   YEQ       BUDGET
   UOBJEQ    OBJECTIVE FUNCTION
   EQUILEQ(I) MARKET EQILIBRIUM
   ;
*----------------------- INITIAL VALUE DEFINITION ------------------------------
   W.L        =  1;
   R.L        =  1;
   P.L(I)     =  1;
   L.L("S1")  =  50;
   L.L("S2")  = 100;
   K.L("S1")  = 100;
   K.L("S2")  = 100;
   LS.L       = SUM(I, L.L(I));
   KS.L       = SUM(I, K.L(I));
   X.L("S1")  = 150;
   X.L("S2")  = 200;
*   BETA(I)    = W.L*L.L(I)/(P.L(I)*X.L(I));
   BETA("S1") = 1/3;
   BETA("S2") = 1/2;
   A(I)       = X.L(I)/ ((L.L(I)**BETA(I))*(K.L(I)**(1-BETA(I))));
   COST.L(I)  = L.L(I)*W.L + K.L(I)*R.L;
   XOBJ.L     = SUM(I, X.L(I));

   ALPHA     = 3/7;
   C.L("S1") = 150;
   C.L("S2") = 200;
   Y.L       = 350;
   U.L = (C.L("S1")**ALPHA)*(C.L("S2")**(1-ALPHA));
*----------------------- EQUATION BLOCK DEFINITION -----------------------------
   COSTEQ(I)..     COST(I) =E= L(I)*W + K(I)*R ;
   XEQ(I)..        X(I) =E= A(I)*(L(I)**BETA(I))*(K(I)**(1-BETA(I))) ;
   LDEMEQ(I)..     L(I) =E= P(I)*X(I)*BETA(I)/W;
   KDEMEQ(I)..     K(I) =E= P(I)*X(I)*(1-BETA(I))/R;
   LSEQ..          LS   =E= SUM(I, L(I)) ;
   KSEQ..          KS   =E= SUM(I, K(I)) ;
   XOBJEQ..        XOBJ =E= SUM(I, X(I)) ;

   CEQ1..          C("S1") =E= ALPHA*Y/P("S1");
   CEQ2..          C("S2") =E= (1-ALPHA)*Y/P("S2");
   YEQ..           Y =E= SUM(I, P(I)*C(I));
   UOBJEQ..        U =E= (C("S1")**ALPHA)*(C("S2")**(1-ALPHA)) ;
   EQUILEQ(I)..    X(I) =E= C(I)            ;
*------------------------- EXOGENOUS VARIABLES --------------------------------
   LS.FX           = LS.L*1.0;
   KS.FX           = KS.L*1.0;
*----------------------- CLOSING --------------------------- -------------------
MODEL   TWOSECTOR MODEL / ALL / ;
options iterlim=1000,limrow=0,limcol=0,domlim=0 ;
options reslim = 1500;
options nlp=CONOPT;
options solprint=OFF;
SOLVE   TWOSECTOR MAXMIZING XOBJ USING NLP;
option  decimals=3;
DISPLAY XOBJ.L, LS.L, KS.L, W.L, R.L ;